@@ -7,11 +7,11 @@
    This program was developed for use in
    gpsman --- GPS Manager: a manager for GPS receiver data
 
-   Copyright (c) 2003 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+   Copyright (c) 2003-2011 Miguel Filgueiras (migf@portugalmail.pt)
 
     This program is free software; you can redistribute it and/or modify
       it under the terms of the GNU General Public License as published by
-      the Free Software Foundation; either version 2 of the License, or
+      the Free Software Foundation; either version 3 of the License, or
       (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -50,6 +50,9 @@
 
 -----
 Revision history:
+1.2.1   08-Jun-11
+         path to shapefil.h
+         change of author email address
 1.2     05-Jul-04, reads .dbf fields for WP and UNKNOWN from files not written
          by gpsmanshp
 1.1     17-Nov-03, reads POLYGON/Z Shapes as UNKNOWN, and ARCM and POLYGONM as
@@ -63,14 +66,14 @@ Revision history:
 \*---------------------------------------------------------------------------*/
 
 /* File: gpsmanshp.c *\
-\* Last modified: 8 July 2004 */
+\* Last modified: 8 June 2011 */
 
 #include <stdlib.h>
 #include <string.h>
-#include <libshp/shapefil.h>
+#include <shapefil.h>
 #include <tcl.h>
 
-#define VERSION "1.2"
+#define VERSION "1.2.1"
 
 // #define DEBUG 1
 
